pub struct AnimeFields { /* private fields */ }Implementations
Sourceimpl AnimeFields
impl AnimeFields
pub const ID: Self
pub const Title: Self
pub const MainPicture: Self
pub const AlternativeTitles: Self
pub const StartDate: Self
pub const EndDate: Self
pub const Synopsis: Self
pub const Mean: Self
pub const Rank: Self
pub const Popularity: Self
pub const NumListUsers: Self
pub const NumScoringUsers: Self
pub const NSFW: Self
pub const CreatedAt: Self
pub const UpdatedAt: Self
pub const MediaType: Self
pub const Status: Self
pub const Genres: Self
pub const MyListStatus: Self
pub const NumEpisodes: Self
pub const StartSeason: Self
pub const Broadcast: Self
pub const Source: Self
pub const AverageEpisodeDuration: Self
pub const Rating: Self
pub const Pictures: Self
pub const Background: Self
pub const RelatedAnime: Self
pub const RelatedManga: Self
pub const Recommendations: Self
pub const Studios: Self
pub const Statistics: Self
pub const ALL: Self
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: u32) -> Self
pub const unsafe fn from_bits_unchecked(bits: u32) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.
Sourceimpl AnimeFields
impl AnimeFields
Sourcepub fn get_fields_names(self) -> Vec<&'static str>
pub fn get_fields_names(self) -> Vec<&'static str>
Returns a list of names of all contained fields.
Sourceimpl AnimeFields
impl AnimeFields
pub fn id(self) -> bool
pub fn title(self) -> bool
pub fn main_picture(self) -> bool
pub fn alternative_titles(self) -> bool
pub fn start_date(self) -> bool
pub fn end_date(self) -> bool
pub fn synopsis(self) -> bool
pub fn mean(self) -> bool
pub fn rank(self) -> bool
pub fn popularity(self) -> bool
pub fn num_list_users(self) -> bool
pub fn num_scoring_users(self) -> bool
pub fn nsfw(self) -> bool
pub fn created_at(self) -> bool
pub fn updated_at(self) -> bool
pub fn media_type(self) -> bool
pub fn status(self) -> bool
pub fn genres(self) -> bool
pub fn my_list_status(self) -> bool
pub fn num_episodes(self) -> bool
pub fn start_season(self) -> bool
pub fn broadcast(self) -> bool
pub fn source(self) -> bool
pub fn average_episode_duration(self) -> bool
pub fn rating(self) -> bool
pub fn pictures(self) -> bool
pub fn background(self) -> bool
pub fn recommendations(self) -> bool
pub fn studios(self) -> bool
pub fn statistics(self) -> bool